@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_cloudwatch._jsii
-import aws_cdk.aws_cloudwatch_actions._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.aws_sns_subscriptions._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "aws-cdk-billing-alarm",
-    "1.0.2",
+    "1.1.0",
     __name__[0:-6],
-    "aws-cdk-billing-alarm@1.0.2.jsii.tgz",
+    "aws-cdk-billing-alarm@1.1.0.jsii.tgz",
 )
 
 __all__ = [
